@@ -821,7 +821,7 @@ sub smokedb_data {
         (my $ncpu      = $si->ncpu          || "?") =~ s/^\s*(\d+)\s*/$1/;
         (my $user_note = $self->{user_note} || "")  =~ s/(\S)[\s\r\n]*\z/$1\n/;
         {
-            architecture     => $si->cpu_type,
+            architecture     => lc $si->cpu_type,
             config_count     => $self->{_rpt}{count},
             cpu_count        => $ncpu,
             cpu_description  => $si->cpu,
@@ -1034,7 +1034,11 @@ sub user_skipped_tests {
     if ($self->{skip_tests} && -f $self->{skip_tests} and open my $fh,
         "<", $self->{skip_tests})
     {
-        @skipped = map { chomp; "    $_" } <$fh>;
+        while (my $raw = <$fh>) {
+            next, if $raw =~ m/^# One test name on a line/;
+            chomp($raw);
+            push @skipped,  "    $raw";
+        }
         close $fh;
     }
     wantarray and return @skipped;
@@ -1130,7 +1134,7 @@ sub preamble {
         version libc gnulibc_version
     ));
     my $si = System::Info->new;
-    my $archname  = $si->cpu_type;
+    my $archname  = lc $si->cpu_type;
 
     (my $ncpu = $si->ncpu || "") =~ s/^(\d+)\s*/$1 cpu/;
     $archname .= "/$ncpu";
